@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class DOTConfig(AppConfig):
-    name = 'oauth2_provider'
+    name = "oauth2_provider"
     verbose_name = "Django OAuth Toolkit"
