@@ -9,16 +9,14 @@ class OAuth2Authentication(BaseAuthentication):
     """
     OAuth 2 authentication backend using `django-oauth-toolkit`
     """
+
     www_authenticate_realm = "api"
 
     def _dict_to_string(self, my_dict):
         """
         Return a string of comma-separated key-value pairs (e.g. k="v",k2="v2").
         """
-        return ",".join([
-            '{k}="{v}"'.format(k=k, v=v)
-            for k, v in my_dict.items()
-        ])
+        return ",".join(['{k}="{v}"'.format(k=k, v=v) for k, v in my_dict.items()])
 
     def authenticate(self, request):
         """
@@ -36,9 +34,11 @@ class OAuth2Authentication(BaseAuthentication):
         """
         Bearer is the only finalized type currently
         """
-        www_authenticate_attributes = OrderedDict([
-            ("realm", self.www_authenticate_realm,),
-        ])
+        www_authenticate_attributes = OrderedDict(
+            [
+                ("realm", self.www_authenticate_realm),
+            ]
+        )
         oauth2_error = getattr(request, "oauth2_error", {})
         www_authenticate_attributes.update(oauth2_error)
         return "Bearer {attributes}".format(
