@@ -23,9 +23,22 @@ management_urlpatterns = [
     re_path(r"^applications/(?P<pk>[\w-]+)/update/$", views.ApplicationUpdate.as_view(), name="update"),
     # Token management views
     re_path(r"^authorized_tokens/$", views.AuthorizedTokensListView.as_view(), name="authorized-token-list"),
-    re_path(r"^authorized_tokens/(?P<pk>[\w-]+)/delete/$", views.AuthorizedTokenDeleteView.as_view(),
-            name="authorized-token-delete"),
+    re_path(
+        r"^authorized_tokens/(?P<pk>[\w-]+)/delete/$",
+        views.AuthorizedTokenDeleteView.as_view(),
+        name="authorized-token-delete",
+    ),
+]
+
+oidc_urlpatterns = [
+    re_path(
+        r"^\.well-known/openid-configuration/$",
+        views.ConnectDiscoveryInfoView.as_view(),
+        name="oidc-connect-discovery-info",
+    ),
+    re_path(r"^\.well-known/jwks.json$", views.JwksInfoView.as_view(), name="jwks-info"),
+    re_path(r"^userinfo/$", views.UserInfoView.as_view(), name="user-info"),
 ]
 
 
-urlpatterns = base_urlpatterns + management_urlpatterns
+urlpatterns = base_urlpatterns + management_urlpatterns + oidc_urlpatterns
