@@ -10,12 +10,9 @@ class URIValidator(URLValidator):
     scheme_re = r"^(?:[a-z][a-z0-9\.\-\+]*)://"
 
     dotless_domain_re = r"(?!-)[A-Z\d-]{1,63}(?<!-)"
-    host_re = "|".join((
-        r"(?:" + URLValidator.host_re,
-        URLValidator.ipv4_re,
-        URLValidator.ipv6_re,
-        dotless_domain_re + ")"
-    ))
+    host_re = "|".join(
+        (r"(?:" + URLValidator.host_re, URLValidator.ipv4_re, URLValidator.ipv6_re, dotless_domain_re + ")")
+    )
     port_re = r"(?::\d{2,5})?"
     path_re = r"(?:[/?#][^\s]*)?"
     regex = re.compile(scheme_re + host_re + port_re + path_re, re.IGNORECASE)
@@ -39,9 +36,11 @@ class RedirectURIValidator(URIValidator):
 # This is required in order to move validation of the scheme from
 # URLValidator (the base class of URIValidator), to OAuth2Application.clean().
 
+
 class WildcardSet(set):
     """
     A set that always returns True on `in`.
     """
+
     def __contains__(self, item):
         return True
