@@ -1,9 +1,7 @@
 from django.contrib.auth.mixins import LoginRequiredMixin
 from django.forms.models import modelform_factory
 from django.urls import reverse_lazy
-from django.views.generic import (
-    CreateView, DeleteView, DetailView, ListView, UpdateView
-)
+from django.views.generic import CreateView, DeleteView, DetailView, ListView, UpdateView
 
 from ..models import get_application_model
 
@@ -12,6 +10,7 @@ class ApplicationOwnerIsUserMixin(LoginRequiredMixin):
     """
     This mixin is used to provide an Application queryset filtered by the current request.user.
     """
+
     fields = "__all__"
 
     def get_queryset(self):
@@ -22,6 +21,7 @@ class ApplicationRegistration(LoginRequiredMixin, CreateView):
     """
     View used to register a new Application for the request.user
     """
+
     template_name = "oauth2_provider/application_registration_form.html"
 
     def get_form_class(self):
@@ -31,9 +31,14 @@ class ApplicationRegistration(LoginRequiredMixin, CreateView):
         return modelform_factory(
             get_application_model(),
             fields=(
-                "name", "client_id", "client_secret", "client_type",
-                "authorization_grant_type", "redirect_uris"
-            )
+                "name",
+                "client_id",
+                "client_secret",
+                "client_type",
+                "authorization_grant_type",
+                "redirect_uris",
+                "algorithm",
+            ),
         )
 
     def form_valid(self, form):
@@ -45,6 +50,7 @@ class ApplicationDetail(ApplicationOwnerIsUserMixin, DetailView):
     """
     Detail view for an application instance owned by the request.user
     """
+
     context_object_name = "application"
     template_name = "oauth2_provider/application_detail.html"
 
@@ -53,6 +59,7 @@ class ApplicationList(ApplicationOwnerIsUserMixin, ListView):
     """
     List view for all the applications owned by the request.user
     """
+
     context_object_name = "applications"
     template_name = "oauth2_provider/application_list.html"
 
@@ -61,6 +68,7 @@ class ApplicationDelete(ApplicationOwnerIsUserMixin, DeleteView):
     """
     View used to delete an application owned by the request.user
     """
+
     context_object_name = "application"
     success_url = reverse_lazy("oauth2_provider:list")
     template_name = "oauth2_provider/application_confirm_delete.html"
@@ -70,6 +78,7 @@ class ApplicationUpdate(ApplicationOwnerIsUserMixin, UpdateView):
     """
     View used to update an application owned by the request.user
     """
+
     context_object_name = "application"
     template_name = "oauth2_provider/application_form.html"
 
@@ -80,7 +89,12 @@ class ApplicationUpdate(ApplicationOwnerIsUserMixin, UpdateView):
         return modelform_factory(
             get_application_model(),
             fields=(
-                "name", "client_id", "client_secret", "client_type",
-                "authorization_grant_type", "redirect_uris"
-            )
+                "name",
+                "client_id",
+                "client_secret",
+                "client_type",
+                "authorization_grant_type",
+                "redirect_uris",
+                "algorithm",
+            ),
         )
