@@ -1,26 +1,19 @@
 from django.views.generic import View
 
-from ..settings import oauth2_settings
 from .mixins import (
-    ClientProtectedResourceMixin, OAuthLibMixin, ProtectedResourceMixin,
-    ReadWriteScopedResourceMixin, ScopedResourceMixin
+    ClientProtectedResourceMixin,
+    OAuthLibMixin,
+    ProtectedResourceMixin,
+    ReadWriteScopedResourceMixin,
+    ScopedResourceMixin,
 )
 
 
-class InitializationMixin(OAuthLibMixin):
-
-    """Initializer for OauthLibMixin
-    """
-
-    server_class = oauth2_settings.OAUTH2_SERVER_CLASS
-    validator_class = oauth2_settings.OAUTH2_VALIDATOR_CLASS
-    oauthlib_backend_class = oauth2_settings.OAUTH2_BACKEND_CLASS
-
-
-class ProtectedResourceView(ProtectedResourceMixin, InitializationMixin, View):
+class ProtectedResourceView(ProtectedResourceMixin, OAuthLibMixin, View):
     """
     Generic view protecting resources by providing OAuth2 authentication out of the box
     """
+
     pass
 
 
@@ -29,6 +22,7 @@ class ScopedProtectedResourceView(ScopedResourceMixin, ProtectedResourceView):
     Generic view protecting resources by providing OAuth2 authentication and Scopes handling
     out of the box
     """
+
     pass
 
 
@@ -37,10 +31,11 @@ class ReadWriteScopedResourceView(ReadWriteScopedResourceMixin, ProtectedResourc
     Generic view protecting resources with OAuth2 authentication and read/write scopes.
     GET, HEAD, OPTIONS http methods require "read" scope. Otherwise "write" scope is required.
     """
+
     pass
 
 
-class ClientProtectedResourceView(ClientProtectedResourceMixin, InitializationMixin, View):
+class ClientProtectedResourceView(ClientProtectedResourceMixin, OAuthLibMixin, View):
 
     """View for protecting a resource with client-credentials method.
     This involves allowing access tokens, Basic Auth and plain credentials in request body.
@@ -51,7 +46,6 @@ class ClientProtectedResourceView(ClientProtectedResourceMixin, InitializationMi
 
 class ClientProtectedScopedResourceView(ScopedResourceMixin, ClientProtectedResourceView):
 
-    """Impose scope restrictions if client protection fallsback to access token.
-    """
+    """Impose scope restrictions if client protection fallsback to access token."""
 
     pass
