@@ -9,6 +9,7 @@ class AuthorizedTokensListView(LoginRequiredMixin, ListView):
     """
     Show a page where the current logged-in user can see his tokens so they can revoke them
     """
+
     context_object_name = "authorized_tokens"
     template_name = "oauth2_provider/authorized-tokens.html"
     model = get_access_token_model()
@@ -17,15 +18,14 @@ class AuthorizedTokensListView(LoginRequiredMixin, ListView):
         """
         Show only user"s tokens
         """
-        return super().get_queryset().select_related("application").filter(
-            user=self.request.user
-        )
+        return super().get_queryset().select_related("application").filter(user=self.request.user)
 
 
 class AuthorizedTokenDeleteView(LoginRequiredMixin, DeleteView):
     """
     View for revoking a specific token
     """
+
     template_name = "oauth2_provider/authorized-token-delete.html"
     success_url = reverse_lazy("oauth2_provider:authorized-token-list")
     model = get_access_token_model()
