@@ -1,8 +1,10 @@
 from django.db import models
 
 from oauth2_provider.models import (
-    AbstractAccessToken, AbstractApplication,
-    AbstractGrant, AbstractRefreshToken
+    AbstractAccessToken,
+    AbstractApplication,
+    AbstractGrant,
+    AbstractRefreshToken,
 )
 from oauth2_provider.settings import oauth2_settings
 
@@ -13,7 +15,7 @@ class BaseTestApplication(AbstractApplication):
     def get_allowed_schemes(self):
         if self.allowed_schemes:
             return self.allowed_schemes.split()
-        return super(BaseTestApplication, self).get_allowed_schemes()
+        return super().get_allowed_schemes()
 
 
 class SampleApplication(AbstractApplication):
@@ -24,16 +26,22 @@ class SampleAccessToken(AbstractAccessToken):
     custom_field = models.CharField(max_length=255)
     source_refresh_token = models.OneToOneField(
         # unique=True implied by the OneToOneField
-        oauth2_settings.REFRESH_TOKEN_MODEL, on_delete=models.SET_NULL, blank=True, null=True,
-        related_name="s_refreshed_access_token"
+        oauth2_settings.REFRESH_TOKEN_MODEL,
+        on_delete=models.SET_NULL,
+        blank=True,
+        null=True,
+        related_name="s_refreshed_access_token",
     )
 
 
 class SampleRefreshToken(AbstractRefreshToken):
     custom_field = models.CharField(max_length=255)
     access_token = models.OneToOneField(
-        oauth2_settings.ACCESS_TOKEN_MODEL, on_delete=models.SET_NULL, blank=True, null=True,
-        related_name="s_refresh_token"
+        oauth2_settings.ACCESS_TOKEN_MODEL,
+        on_delete=models.SET_NULL,
+        blank=True,
+        null=True,
+        related_name="s_refresh_token",
     )
 
 
