@@ -1,7 +1,10 @@
 import json
+from unittest.mock import patch
 from urllib.parse import quote_plus
 
+import pytest
 from django.contrib.auth import get_user_model
+from django.core.exceptions import SuspiciousOperation
 from django.test import RequestFactory, TestCase
 from django.urls import reverse
 from django.views.generic import View
@@ -10,10 +13,10 @@ from oauthlib.oauth2 import BackendApplicationServer
 from oauth2_provider.models import get_access_token_model, get_application_model
 from oauth2_provider.oauth2_backends import OAuthLibCore
 from oauth2_provider.oauth2_validators import OAuth2Validator
-from oauth2_provider.settings import oauth2_settings
 from oauth2_provider.views import ProtectedResourceView
 from oauth2_provider.views.mixins import OAuthLibMixin
 
+from . import presets
 from .utils import get_basic_auth_header
 
 
@@ -28,6 +31,8 @@ class ResourceView(ProtectedResourceView):
         return "This is a protected resource"
 
 
+@pytest.mark.usefixtures("oauth2_settings")
+@pytest.mark.oauth2_settings(presets.DEFAULT_SCOPES_RW)
 class BaseTest(TestCase):
     def setUp(self):
         self.factory = RequestFactory()
@@ -41,9 +46,6 @@ class BaseTest(TestCase):
             authorization_grant_type=Application.GRANT_CLIENT_CREDENTIALS,
         )
 
-        oauth2_settings._SCOPES = ["read", "write"]
-        oauth2_settings._DEFAULT_SCOPES = ["read", "write"]
-
     def tearDown(self):
         self.application.delete()
         self.test_user.delete()
@@ -101,21 +103,22 @@ class TestClientCredential(BaseTest):
         self.assertIsNone(access_token.user)
 
 
+class TestView(OAuthLibMixin, View):
+    server_class = BackendApplicationServer
+    validator_class = OAuth2Validator
+    oauthlib_backend_class = OAuthLibCore
+
+    def get_scopes(self):
+        return ["read", "write"]
+
+
 class TestExtendedRequest(BaseTest):
     @classmethod
     def setUpClass(cls):
         cls.request_factory = RequestFactory()
-        super(TestExtendedRequest, cls).setUpClass()
+        super().setUpClass()
 
     def test_extended_request(self):
-        class TestView(OAuthLibMixin, View):
-            server_class = BackendApplicationServer
-            validator_class = OAuth2Validator
-            oauthlib_backend_class = OAuthLibCore
-
-            def get_scopes(self):
-                return ["read", "write"]
-
         token_request_data = {
             "grant_type": "client_credentials",
         }
@@ -143,6 +146,21 @@ class TestExtendedRequest(BaseTest):
         self.assertEqual(r.client, self.application)
         self.assertEqual(r.scopes, ["read", "write"])
 
+    def test_raises_error_with_invalid_hex_in_query_params(self):
+        request = self.request_factory.get("/fake-req?auth_token=%%7A")
+
+        with pytest.raises(SuspiciousOperation):
+            TestView().verify_request(request)
+
+    @patch("oauth2_provider.views.mixins.OAuthLibMixin.get_oauthlib_core")
+    def test_reraises_value_errors_as_is(self, patched_core):
+        patched_core.return_value.verify_request.side_effect = ValueError("Generic error")
+
+        request = self.request_factory.get("/fake-req")
+
+        with pytest.raises(ValueError):
+            TestView().verify_request(request)
+
 
 class TestClientResourcePasswordBased(BaseTest):
     def test_client_resource_password_based(self):
@@ -158,11 +176,7 @@ class TestClientResourcePasswordBased(BaseTest):
             authorization_grant_type=Application.GRANT_PASSWORD,
         )
 
-        token_request_data = {
-            "grant_type": "password",
-            "username": "test_user",
-            "password": "123456"
-        }
+        token_request_data = {"grant_type": "password", "username": "test_user", "password": "123456"}
         auth_headers = get_basic_auth_header(
             quote_plus(self.application.client_id), quote_plus(self.application.client_secret)
         )
