@@ -6,7 +6,6 @@ from django.utils import timezone
 
 from oauth2_provider.decorators import protected_resource, rw_protected_resource
 from oauth2_provider.models import get_access_token_model, get_application_model
-from oauth2_provider.settings import oauth2_settings
 
 
 Application = get_application_model()
@@ -18,7 +17,7 @@ class TestProtectedResourceDecorator(TestCase):
     @classmethod
     def setUpClass(cls):
         cls.request_factory = RequestFactory()
-        super(TestProtectedResourceDecorator, cls).setUpClass()
+        super().setUpClass()
 
     def setUp(self):
         self.user = UserModel.objects.create_user("test_user", "test@example.com", "123456")
@@ -34,11 +33,9 @@ class TestProtectedResourceDecorator(TestCase):
             scope="read write",
             expires=timezone.now() + timedelta(seconds=300),
             token="secret-access-token-key",
-            application=self.application
+            application=self.application,
         )
 
-        oauth2_settings._SCOPES = ["read", "write"]
-
     def test_access_denied(self):
         @protected_resource()
         def view(request, *args, **kwargs):
